# Examples

* `digit_recognition` - supervised training of a neural network to recognise
  hand-written numerals `0`-`9`. See this in action online here:
  [ntoll.pyscriptapps.com/sann-character-recognition](https://ntoll.pyscriptapps.com/sann-character-recognition)
* `snAIke` - unsupervised training (via evolution) of a neural network that
  controls a snake looking for food in a simple 2d game world. See it in
  action here: [https://ntoll.pyscriptapps.com/snakegame/](https://ntoll.pyscriptapps.com/snakegame/)
  (Play with the arrow keys, or click the `[]`🤖 checkbox to toggle the AI
  autopilot.)